@@ -6,13 +6,12 @@ from typing import Any, Dict, cast
 
 import parse
 
-from behave.runner import Context
-from behave import register_type, given  # pylint: disable=no-name-in-module
 from grizzly_extras.text import permutation
 
-from ...context import GrizzlyContext
-from ...testdata.utils import resolve_variable
-from .._helpers import is_template
+from grizzly.types.behave import Context, given, register_type
+from grizzly.context import GrizzlyContext
+from grizzly.testdata.utils import resolve_variable
+from grizzly.steps._helpers import is_template
 
 
 @parse.with_pattern(r'(user[s]?)')
