@@ -4,11 +4,9 @@ This module contains step implementations that describes a {@pylink grizzly.user
 """
 from typing import cast
 
-from behave.runner import Context
-from behave import given  # pylint: disable=no-name-in-module
-
-from ...context import GrizzlyContext
-from ...testdata.utils import resolve_variable
+from grizzly.types.behave import Context, given
+from grizzly.context import GrizzlyContext
+from grizzly.testdata.utils import resolve_variable
 
 
 @given(u'a user of type "{user_class_name}" with weight "{weight_value}" load testing "{host}"')
