@@ -16,12 +16,11 @@ Given a user of type "Dummy" load testing "/dev/null"
 '''
 from typing import Any, Dict, Tuple
 
-from locust.env import Environment
-
 from grizzly.types import GrizzlyResponse
+from grizzly.types.locust import Environment
+from grizzly.tasks import RequestTask
 
 from .base import GrizzlyUser
-from ..tasks import RequestTask
 
 
 class DummyUser(GrizzlyUser):
