@@ -78,16 +78,15 @@ from zmq.error import Again as ZMQAgain
 from zmq.sugar.constants import NOBLOCK as ZMQ_NOBLOCK, REQ as ZMQ_REQ
 import zmq.green as zmq
 
-from locust.exception import StopUser
-from locust.env import Environment
 from gevent import sleep as gsleep
 from grizzly_extras.async_message import AsyncMessageContext, AsyncMessageResponse, AsyncMessageRequest, AsyncMessageError
 from grizzly_extras.arguments import parse_arguments, get_unsupported_arguments
 
 from grizzly.types import RequestMethod, RequestDirection, GrizzlyResponse, RequestType
+from grizzly.types.locust import StopUser, Environment
+from grizzly.tasks import RequestTask
+from grizzly.utils import merge_dicts
 
-from ..tasks import RequestTask
-from ..utils import merge_dicts
 from .base import GrizzlyUser, ResponseHandler, RequestLogger
 from . import logger
 
@@ -150,6 +149,10 @@ class ServiceBusUser(ResponseHandler, RequestLogger, GrizzlyUser):
 
         self.hellos = set()
         self.worker_id = None
+
+    def on_start(self) -> None:
+        super().on_start()
+
         self.zmq_client = self.zmq_context.socket(ZMQ_REQ)
         self.zmq_client.connect(self.zmq_url)
 
@@ -161,10 +164,23 @@ class ServiceBusUser(ResponseHandler, RequestLogger, GrizzlyUser):
                 endpoint = task.endpoint
                 self.say_hello(task, endpoint)
 
-    def say_hello(self, task: RequestTask, endpoint: str) -> None:
+    def on_stop(self) -> None:
+        if getattr(self, '_scenario', None) is not None:
+            for task in self._scenario.tasks:
+                if not isinstance(task, RequestTask):
+                    continue
+
+                endpoint = task.endpoint
+                self.disconnect(task, endpoint)
+
+        self.zmq_client.disconnect(self.zmq_url)
+
+        super().on_stop()
+
+    def get_description(self, task: RequestTask, endpoint: str) -> str:
         if ('{{' in endpoint and '}}' in endpoint) or '$conf' in endpoint or '$env' in endpoint:
-            logger.warning(f'{self.__class__.__name__}: cannot say hello for {task.name} when endpoint is a template')
-            return
+            logger.error(f'{self.__class__.__name__}: cannot say hello for {task.name} when endpoint is a template')
+            raise StopUser()
 
         connection = 'sender' if task.method.direction == RequestDirection.TO else 'receiver'
 
@@ -181,11 +197,45 @@ class ServiceBusUser(ResponseHandler, RequestLogger, GrizzlyUser):
 
         cache_endpoint = ', '.join([f'{key}:{value}' for key, value in endpoint_arguments.items()])
 
-        description = f'{connection}={cache_endpoint}'
+        return f'{connection}={cache_endpoint}'
+
+    def disconnect(self, task: RequestTask, endpoint: str) -> None:
+        description = self.get_description(task, endpoint)
+
+        if description not in self.hellos:
+            return
+
+        _, cache_endpoint = description.split('=', 1)
+
+        context = cast(AsyncMessageContext, dict(self.am_context))
+        context.update({
+            'endpoint': cache_endpoint,
+        })
+
+        request: AsyncMessageRequest = {
+            'worker': self.worker_id,
+            'action': RequestType.DISCONNECT.name,
+            'context': context,
+        }
+
+        with self.async_action(task, request, description) as metadata:
+            metadata.update({
+                'meta': True,
+                'failure_exception': None,
+            })
+
+        self.hellos.remove(description)
+
+    def say_hello(self, task: RequestTask, endpoint: str) -> None:
+        description = self.get_description(task, endpoint)
 
         if description in self.hellos:
             return
 
+        _, cache_endpoint = description.split('=', 1)
+
+        arguments = parse_arguments(endpoint, ':')
+
         context = cast(AsyncMessageContext, dict(self.am_context))
         context.update({
             'endpoint': cache_endpoint,
@@ -200,7 +250,7 @@ class ServiceBusUser(ResponseHandler, RequestLogger, GrizzlyUser):
         with self.async_action(task, request, description) as metadata:
             metadata.update({
                 'meta': True,
-                'failure_exception': StopUser,
+                'failure_exception': None,
             })
 
             if 'queue' not in arguments and 'topic' not in arguments:
