@@ -296,3 +296,10 @@ def async_message_request_wrapper(parent: GrizzlyScenario, client: zmq.Socket, r
     request = jsonloads(parent.render(request_json))
 
     return async_message_request(client, request)
+
+
+def safe_del(struct: Dict[str, Any], key: str) -> None:
+    try:
+        del struct[key]
+    except KeyError:
+        pass
