@@ -81,6 +81,7 @@ class TestMessageQueueClientTask:
             assert task_factory.destination is None
             assert task_factory.source is None
             assert not hasattr(task_factory, 'scenario')
+            assert task_factory.__template_attributes__ == {'endpoint', 'destination', 'source', 'name', 'variable_template'}
         finally:
             if zmq_context is not None:
                 zmq_context.destroy()
@@ -102,6 +103,10 @@ class TestMessageQueueClientTask:
             assert task_factory.destination is None
             assert task_factory.source is None
             assert not hasattr(task_factory, 'scenario')
+
+            with pytest.raises(NotImplementedError) as nie:
+                MessageQueueClientTask(RequestDirection.FROM, 'mqs://localhost:1', 'messagequeue-request', text='foobar')
+            assert str(nie.value) == 'MessageQueueClientTask has not implemented support for step text'
         finally:
             if zmq_context is not None:
                 zmq_context.destroy()
@@ -266,8 +271,8 @@ class TestMessageQueueClientTask:
     def test_create_client(self, grizzly_fixture: GrizzlyFixture, noop_zmq: NoopZmqFixture) -> None:
         noop_zmq('grizzly.tasks.clients.messagequeue')
         connect_mock = noop_zmq.get_mock('zmq.Socket.connect')
-        setsockopt_mock = noop_zmq._mocker.patch('grizzly.tasks.clients.messagequeue.zmq.Socket.setsockopt', autospec=True)
-        close_mock = noop_zmq._mocker.patch('grizzly.tasks.clients.messagequeue.zmq.Socket.close')
+        setsockopt_mock = noop_zmq.get_mock('zmq.Socket.setsockopt')
+        close_mock = noop_zmq.get_mock('zmq.Socket.close')
 
         zmq_context: Optional[zmq.Context] = None
         try:
@@ -279,8 +284,9 @@ class TestMessageQueueClientTask:
 
             with task_factory.create_client() as client:
                 assert connect_mock.call_count == 1
-                args, _ = connect_mock.call_args_list[-1]
-                assert args[1] == task_factory._zmq_url
+                args, kwargs = connect_mock.call_args_list[-1]
+                assert args == (task_factory._zmq_url,)
+                assert kwargs == {}
 
                 assert isinstance(client, zmq.Socket)
 
@@ -312,7 +318,6 @@ class TestMessageQueueClientTask:
             zmq_context = task_factory._zmq_context
 
             with task_factory.create_client() as client:
-                noop_zmq._mocker.patch('grizzly.tasks.clients.messagequeue.zmq.Socket.setsockopt', autospec=True)
                 meta: Dict[str, Any] = {}
                 with pytest.raises(RuntimeError) as re:
                     task_factory.connect(111111, client, meta)
@@ -322,8 +327,8 @@ class TestMessageQueueClientTask:
                 assert meta.get('direction', None) == '<->'
 
                 assert send_json_mock.call_count == 1
-                args, _ = send_json_mock.call_args_list[-1]
-                assert args[1] == {
+                args, kwargs = send_json_mock.call_args_list[-1]
+                assert args == ({
                     'action': 'CONN',
                     'context': {
                         'url': task_factory.endpoint,
@@ -339,7 +344,8 @@ class TestMessageQueueClientTask:
                         'heartbeat_interval': None,
                         'header_type': None,
                     },
-                }
+                },)
+                assert kwargs == {}
                 assert recv_json_mock.call_count == 2
                 _, kwargs = recv_json_mock.call_args_list[-1]
                 assert kwargs.get('flags', None) == zmq.NOBLOCK
@@ -384,8 +390,8 @@ class TestMessageQueueClientTask:
                 task_factory.connect(444444, client, meta)
                 assert send_json_mock.call_count == 4
                 assert recv_json_mock.call_count == 5
-                args, _ = send_json_mock.call_args_list[-1]
-                assert args[1] == {
+                args, kwargs = send_json_mock.call_args_list[-1]
+                assert args == ({
                     'action': 'CONN',
                     'context': {
                         'url': task_factory.endpoint,
@@ -401,7 +407,8 @@ class TestMessageQueueClientTask:
                         'heartbeat_interval': None,
                         'header_type': 'rfh2',
                     },
-                }
+                },)
+                assert kwargs == {}
 
         finally:
             if zmq_context is not None:
@@ -442,15 +449,16 @@ class TestMessageQueueClientTask:
             assert scenario.user._context['variables'].get('mq-client-var', None) is None
             assert task_factory._worker.get(id(scenario), None) == 'dddd-eeee-ffff-9999'
             assert send_json_mock.call_count == 2
-            args, _ = send_json_mock.call_args_list[-1]
-            assert args[1] == {
+            args, kwargs = send_json_mock.call_args_list[-1]
+            assert args == ({
                 'action': 'GET',
                 'worker': 'dddd-eeee-ffff-9999',
                 'context': {
                     'endpoint': 'topic:INCOMING.MSG',
                 },
                 'payload': None,
-            }
+            },)
+            assert kwargs == {}
             assert recv_json_mock.call_count == 3
 
             assert fire_spy.call_count == 1
@@ -476,15 +484,16 @@ class TestMessageQueueClientTask:
 
             assert scenario.user._context['variables'].get('mq-client-var', None) is None
             assert send_json_mock.call_count == 3
-            args, _ = send_json_mock.call_args_list[-1]
-            assert args[1] == {
+            args, kwargs = send_json_mock.call_args_list[-1]
+            assert args == ({
                 'action': 'GET',
                 'worker': 'dddd-eeee-ffff-9999',
                 'context': {
                     'endpoint': 'topic:INCOMING.MSG, max_message_size:13337',
                 },
                 'payload': None,
-            }
+            },)
+            assert kwargs == {}
             assert recv_json_mock.call_count == 4
 
             assert fire_spy.call_count == 2
@@ -591,15 +600,16 @@ class TestMessageQueueClientTask:
 
             assert recv_json_mock.call_count == 2
             assert send_json_mock.call_count == 2
-            args, _ = send_json_mock.call_args_list[-1]
-            assert args[1] == {
+            args, kwargs = send_json_mock.call_args_list[-1]
+            assert args == ({
                 'action': 'PUT',
                 'worker': 'dddd-eeee-ffff-9999',
                 'context': {
                     'endpoint': 'queue:INCOMING.MSG',
                 },
                 'payload': source,
-            }
+            },)
+            assert kwargs == {}
 
             assert fire_spy.call_count == 1
             _, kwargs = fire_spy.call_args_list[-1]
@@ -623,15 +633,16 @@ class TestMessageQueueClientTask:
 
             assert recv_json_mock.call_count == 3
             assert send_json_mock.call_count == 3
-            args, _ = send_json_mock.call_args_list[-1]
-            assert args[1] == {
+            args, kwargs = send_json_mock.call_args_list[-1]
+            assert args == ({
                 'action': 'PUT',
                 'worker': 'dddd-eeee-ffff-9999',
                 'context': {
                     'endpoint': 'queue:INCOMING.MSG',
                 },
                 'payload': source_file.read_text(),
-            }
+            },)
+            assert kwargs == {}
 
             assert fire_spy.call_count == 2
             _, kwargs = fire_spy.call_args_list[-1]
